window.Gleam.initSearch([{"doc":"convert_http_query","title":"convert_http_query","content":"# convert_http_query\n\n[![Package Version](https://img.shields.io/hexpm/v/convert_http_query)](https://hex.pm/packages/convert_http_query)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/convert_http_query/)\n\n**Encode and decode HTTP queries from/to Gleam types**\n\nEasily convert your Gleam types to HTTP queries. This is particularly useful to have typed queries automatically encoded in your frontend and decoded in your backend.\n\n## Installation\n\n```sh\ngleam add convert_http_query@1\n```\n\n## Usage\n\n```gleam\nimport convert\nimport convert/http/query\n\npub type User {\n  User(name: String, age: Int, children: List(String))\n}\n\npub fn user_converter() {\n  convert.object({\n    use name &lt;- convert.field(&quot;name&quot;, fn (v: User) { Ok(v.name) }, convert.string())\n    use age &lt;- convert.field(&quot;age&quot;, fn (v: User) { Ok(v.age) }, convert.int())\n    use children &lt;- convert.field(&quot;children&quot;, fn (v: User) { Ok(v.children) }, convert.list(convert.string()))\n\n    convert.success(User(name:, age:, children:))\n  })\n}\n\npub fn main() {\n  User(&quot;John&quot;, 42, [&quot;Alice&quot;, &quot;Bob&quot;])\n  |&gt; query.encode(user_converter())\n  // =&gt; [\n  //  #(&quot;name&quot;, &quot;John&quot;),\n  //  #(&quot;age&quot;, &quot;42&quot;),\n  //  #(&quot;children.0&quot;, &quot;Alice&quot;),\n  //  #(&quot;children.1&quot;, &quot;Bob&quot;),\n  // ]\n\n  [\n    #(&quot;name&quot;, &quot;Thomas&quot;),\n    #(&quot;age&quot;, &quot;27&quot;),\n  ]\n  |&gt; query.decode(user_converter())\n  // =&gt; User(&quot;Thomas&quot;, 27, [])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/convert_http_query&gt;.\n\n## Features\n\n- Encode and decode HTTP queries from and to Gleam types\n- Support for all Gleam primitive types\n- Support for lists, results, optionals, dicts\n- Allow decoding to objects and enums\n\n## Limitations\n\nNot all dict keys are supported. Currently, only primitive types such as Bool, Int, Float, String and BitArray.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"convert/http/query","title":"decode","content":"pub fn decode(\n  query: List(#(String, String)),\n  converter: Converter(a),\n) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\nconvert/http/query.decode\nconvert/http/query decode","url":"convert/http/query.html#decode"},{"doc":"convert/http/query","title":"decode_value","content":"pub fn decode_value(\n  of: GlitrType,\n) -&gt; fn(List(#(String, String))) -&gt;\n  Result(GlitrValue, List(DecodeError))\n\nSynonyms:\nconvert/http/query.decode_value\nconvert/http/query decode_value","url":"convert/http/query.html#decode_value"},{"doc":"convert/http/query","title":"encode","content":"pub fn encode(\n  value: a,\n  converter: Converter(a),\n) -&gt; List(#(String, String))\n\nSynonyms:\nconvert/http/query.encode\nconvert/http/query encode","url":"convert/http/query.html#encode"},{"doc":"convert/http/query","title":"encode_value","content":"pub fn encode_value(val: GlitrValue) -&gt; List(#(String, String))\n\nSynonyms:\nconvert/http/query.encode_value\nconvert/http/query encode_value","url":"convert/http/query.html#encode_value"},{"doc":"convert/http/query","title":"convert/http/query","content":"","url":"convert/http/query.html"},{"doc":"convert_http_query","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nconvert_http_query.main\nconvert_http_query main","url":"convert_http_query.html#main"},{"doc":"convert_http_query","title":"convert_http_query","content":"","url":"convert_http_query.html"}]);